# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.team_search200_response import (
    TeamSearch200Response,
)  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestTeamSearch200Response(unittest.TestCase):
    """TeamSearch200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TeamSearch200Response
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TeamSearch200Response`
        """
        model = py_gitea_opensuse_org.models.team_search200_response.TeamSearch200Response()  # noqa: E501
        if include_optional :
            return TeamSearch200Response(
                data = [
                    py_gitea_opensuse_org.models.team.Team(
                        can_create_org_repo = True, 
                        description = '', 
                        id = 56, 
                        includes_all_repositories = True, 
                        name = '', 
                        organization = py_gitea_opensuse_org.models.organization.Organization(
                            avatar_url = '', 
                            description = '', 
                            full_name = '', 
                            id = 56, 
                            location = '', 
                            name = '', 
                            repo_admin_change_team_access = True, 
                            username = '', 
                            visibility = '', 
                            website = '', ), 
                        permission = 'none', 
                        units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                        units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, )
                    ], 
                ok = True
            )
        else :
            return TeamSearch200Response(
        )
        """

    def testTeamSearch200Response(self):
        """Test TeamSearch200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.edit_team_option import EditTeamOption  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestEditTeamOption(unittest.TestCase):
    """EditTeamOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EditTeamOption
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `EditTeamOption`
        """
        model = py_gitea_opensuse_org.models.edit_team_option.EditTeamOption()  # noqa: E501
        if include_optional :
            return EditTeamOption(
                can_create_org_repo = True, 
                description = '', 
                includes_all_repositories = True, 
                name = '', 
                permission = 'read', 
                units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}
            )
        else :
            return EditTeamOption(
                name = '',
        )
        """

    def testEditTeamOption(self):
        """Test EditTeamOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.branch import Branch  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestBranch(unittest.TestCase):
    """Branch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Branch
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Branch`
        """
        model = py_gitea_opensuse_org.models.branch.Branch()  # noqa: E501
        if include_optional :
            return Branch(
                commit = py_gitea_opensuse_org.models.payload_commit.PayloadCommit(
                    added = [
                        ''
                        ], 
                    author = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                        email = '', 
                        name = '', 
                        username = '', ), 
                    committer = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                        email = '', 
                        name = '', 
                        username = '', ), 
                    id = '', 
                    message = '', 
                    modified = [
                        ''
                        ], 
                    removed = [
                        ''
                        ], 
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    verification = py_gitea_opensuse_org.models.payload_commit_verification.PayloadCommitVerification(
                        payload = '', 
                        reason = '', 
                        signature = '', 
                        signer = , 
                        verified = True, ), ), 
                effective_branch_protection_name = '', 
                enable_status_check = True, 
                name = '', 
                protected = True, 
                required_approvals = 56, 
                status_check_contexts = [
                    ''
                    ], 
                user_can_merge = True, 
                user_can_push = True
            )
        else :
            return Branch(
        )
        """

    def testBranch(self):
        """Test Branch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from py_gitea_opensuse_org.models.api_error import APIError
from py_gitea_opensuse_org.models.access_token import AccessToken
from py_gitea_opensuse_org.models.action_artifact import ActionArtifact
from py_gitea_opensuse_org.models.action_artifacts_response import ActionArtifactsResponse
from py_gitea_opensuse_org.models.action_runner import ActionRunner
from py_gitea_opensuse_org.models.action_runner_label import ActionRunnerLabel
from py_gitea_opensuse_org.models.action_runners_response import ActionRunnersResponse
from py_gitea_opensuse_org.models.action_task import ActionTask
from py_gitea_opensuse_org.models.action_task_response import ActionTaskResponse
from py_gitea_opensuse_org.models.action_variable import ActionVariable
from py_gitea_opensuse_org.models.action_workflow import ActionWorkflow
from py_gitea_opensuse_org.models.action_workflow_response import ActionWorkflowResponse
from py_gitea_opensuse_org.models.action_workflow_run import ActionWorkflowRun
from py_gitea_opensuse_org.models.activity import Activity
from py_gitea_opensuse_org.models.activity_pub import ActivityPub
from py_gitea_opensuse_org.models.add_collaborator_option import AddCollaboratorOption
from py_gitea_opensuse_org.models.add_time_option import AddTimeOption
from py_gitea_opensuse_org.models.annotated_tag import AnnotatedTag
from py_gitea_opensuse_org.models.annotated_tag_object import AnnotatedTagObject
from py_gitea_opensuse_org.models.attachment import Attachment
from py_gitea_opensuse_org.models.badge import Badge
from py_gitea_opensuse_org.models.branch import Branch
from py_gitea_opensuse_org.models.branch_protection import BranchProtection
from py_gitea_opensuse_org.models.change_file_operation import ChangeFileOperation
from py_gitea_opensuse_org.models.change_files_options import ChangeFilesOptions
from py_gitea_opensuse_org.models.changed_file import ChangedFile
from py_gitea_opensuse_org.models.combined_status import CombinedStatus
from py_gitea_opensuse_org.models.comment import Comment
from py_gitea_opensuse_org.models.commit import Commit
from py_gitea_opensuse_org.models.commit_affected_files import CommitAffectedFiles
from py_gitea_opensuse_org.models.commit_date_options import CommitDateOptions
from py_gitea_opensuse_org.models.commit_meta import CommitMeta
from py_gitea_opensuse_org.models.commit_stats import CommitStats
from py_gitea_opensuse_org.models.commit_status import CommitStatus
from py_gitea_opensuse_org.models.commit_user import CommitUser
from py_gitea_opensuse_org.models.compare import Compare
from py_gitea_opensuse_org.models.contents_response import ContentsResponse
from py_gitea_opensuse_org.models.create_access_token_option import CreateAccessTokenOption
from py_gitea_opensuse_org.models.create_action_workflow_dispatch import CreateActionWorkflowDispatch
from py_gitea_opensuse_org.models.create_branch_protection_option import CreateBranchProtectionOption
from py_gitea_opensuse_org.models.create_branch_repo_option import CreateBranchRepoOption
from py_gitea_opensuse_org.models.create_email_option import CreateEmailOption
from py_gitea_opensuse_org.models.create_file_options import CreateFileOptions
from py_gitea_opensuse_org.models.create_fork_option import CreateForkOption
from py_gitea_opensuse_org.models.create_gpg_key_option import CreateGPGKeyOption
from py_gitea_opensuse_org.models.create_hook_option import CreateHookOption
from py_gitea_opensuse_org.models.create_issue_comment_option import CreateIssueCommentOption
from py_gitea_opensuse_org.models.create_issue_option import CreateIssueOption
from py_gitea_opensuse_org.models.create_key_option import CreateKeyOption
from py_gitea_opensuse_org.models.create_label_option import CreateLabelOption
from py_gitea_opensuse_org.models.create_milestone_option import CreateMilestoneOption
from py_gitea_opensuse_org.models.create_o_auth2_application_options import CreateOAuth2ApplicationOptions
from py_gitea_opensuse_org.models.create_or_update_secret_option import CreateOrUpdateSecretOption
from py_gitea_opensuse_org.models.create_org_option import CreateOrgOption
from py_gitea_opensuse_org.models.create_pull_request_option import CreatePullRequestOption
from py_gitea_opensuse_org.models.create_pull_review_comment import CreatePullReviewComment
from py_gitea_opensuse_org.models.create_pull_review_options import CreatePullReviewOptions
from py_gitea_opensuse_org.models.create_push_mirror_option import CreatePushMirrorOption
from py_gitea_opensuse_org.models.create_release_option import CreateReleaseOption
from py_gitea_opensuse_org.models.create_repo_option import CreateRepoOption
from py_gitea_opensuse_org.models.create_status_option import CreateStatusOption
from py_gitea_opensuse_org.models.create_tag_option import CreateTagOption
from py_gitea_opensuse_org.models.create_tag_protection_option import CreateTagProtectionOption
from py_gitea_opensuse_org.models.create_team_option import CreateTeamOption
from py_gitea_opensuse_org.models.create_user_option import CreateUserOption
from py_gitea_opensuse_org.models.create_variable_option import CreateVariableOption
from py_gitea_opensuse_org.models.create_wiki_page_options import CreateWikiPageOptions
from py_gitea_opensuse_org.models.cron import Cron
from py_gitea_opensuse_org.models.delete_email_option import DeleteEmailOption
from py_gitea_opensuse_org.models.delete_file_options import DeleteFileOptions
from py_gitea_opensuse_org.models.deploy_key import DeployKey
from py_gitea_opensuse_org.models.dismiss_pull_review_options import DismissPullReviewOptions
from py_gitea_opensuse_org.models.edit_attachment_options import EditAttachmentOptions
from py_gitea_opensuse_org.models.edit_branch_protection_option import EditBranchProtectionOption
from py_gitea_opensuse_org.models.edit_deadline_option import EditDeadlineOption
from py_gitea_opensuse_org.models.edit_git_hook_option import EditGitHookOption
from py_gitea_opensuse_org.models.edit_hook_option import EditHookOption
from py_gitea_opensuse_org.models.edit_issue_comment_option import EditIssueCommentOption
from py_gitea_opensuse_org.models.edit_issue_option import EditIssueOption
from py_gitea_opensuse_org.models.edit_label_option import EditLabelOption
from py_gitea_opensuse_org.models.edit_milestone_option import EditMilestoneOption
from py_gitea_opensuse_org.models.edit_org_option import EditOrgOption
from py_gitea_opensuse_org.models.edit_pull_request_option import EditPullRequestOption
from py_gitea_opensuse_org.models.edit_reaction_option import EditReactionOption
from py_gitea_opensuse_org.models.edit_release_option import EditReleaseOption
from py_gitea_opensuse_org.models.edit_repo_option import EditRepoOption
from py_gitea_opensuse_org.models.edit_tag_protection_option import EditTagProtectionOption
from py_gitea_opensuse_org.models.edit_team_option import EditTeamOption
from py_gitea_opensuse_org.models.edit_user_option import EditUserOption
from py_gitea_opensuse_org.models.email import Email
from py_gitea_opensuse_org.models.external_tracker import ExternalTracker
from py_gitea_opensuse_org.models.external_wiki import ExternalWiki
from py_gitea_opensuse_org.models.file_commit_response import FileCommitResponse
from py_gitea_opensuse_org.models.file_delete_response import FileDeleteResponse
from py_gitea_opensuse_org.models.file_links_response import FileLinksResponse
from py_gitea_opensuse_org.models.file_response import FileResponse
from py_gitea_opensuse_org.models.files_response import FilesResponse
from py_gitea_opensuse_org.models.gpg_key import GPGKey
from py_gitea_opensuse_org.models.gpg_key_email import GPGKeyEmail
from py_gitea_opensuse_org.models.general_api_settings import GeneralAPISettings
from py_gitea_opensuse_org.models.general_attachment_settings import GeneralAttachmentSettings
from py_gitea_opensuse_org.models.general_repo_settings import GeneralRepoSettings
from py_gitea_opensuse_org.models.general_ui_settings import GeneralUISettings
from py_gitea_opensuse_org.models.generate_repo_option import GenerateRepoOption
from py_gitea_opensuse_org.models.get_files_options import GetFilesOptions
from py_gitea_opensuse_org.models.git_blob_response import GitBlobResponse
from py_gitea_opensuse_org.models.git_entry import GitEntry
from py_gitea_opensuse_org.models.git_hook import GitHook
from py_gitea_opensuse_org.models.git_object import GitObject
from py_gitea_opensuse_org.models.git_tree_response import GitTreeResponse
from py_gitea_opensuse_org.models.gitignore_template_info import GitignoreTemplateInfo
from py_gitea_opensuse_org.models.hook import Hook
from py_gitea_opensuse_org.models.identity import Identity
from py_gitea_opensuse_org.models.internal_tracker import InternalTracker
from py_gitea_opensuse_org.models.issue import Issue
from py_gitea_opensuse_org.models.issue_config import IssueConfig
from py_gitea_opensuse_org.models.issue_config_contact_link import IssueConfigContactLink
from py_gitea_opensuse_org.models.issue_config_validation import IssueConfigValidation
from py_gitea_opensuse_org.models.issue_deadline import IssueDeadline
from py_gitea_opensuse_org.models.issue_form_field import IssueFormField
from py_gitea_opensuse_org.models.issue_labels_option import IssueLabelsOption
from py_gitea_opensuse_org.models.issue_meta import IssueMeta
from py_gitea_opensuse_org.models.issue_template import IssueTemplate
from py_gitea_opensuse_org.models.label import Label
from py_gitea_opensuse_org.models.label_template import LabelTemplate
from py_gitea_opensuse_org.models.license_template_info import LicenseTemplateInfo
from py_gitea_opensuse_org.models.licenses_template_list_entry import LicensesTemplateListEntry
from py_gitea_opensuse_org.models.lock_issue_option import LockIssueOption
from py_gitea_opensuse_org.models.markdown_option import MarkdownOption
from py_gitea_opensuse_org.models.markup_option import MarkupOption
from py_gitea_opensuse_org.models.merge_pull_request_option import MergePullRequestOption
from py_gitea_opensuse_org.models.merge_upstream_request import MergeUpstreamRequest
from py_gitea_opensuse_org.models.merge_upstream_response import MergeUpstreamResponse
from py_gitea_opensuse_org.models.migrate_repo_options import MigrateRepoOptions
from py_gitea_opensuse_org.models.milestone import Milestone
from py_gitea_opensuse_org.models.new_issue_pins_allowed import NewIssuePinsAllowed
from py_gitea_opensuse_org.models.node_info import NodeInfo
from py_gitea_opensuse_org.models.node_info_services import NodeInfoServices
from py_gitea_opensuse_org.models.node_info_software import NodeInfoSoftware
from py_gitea_opensuse_org.models.node_info_usage import NodeInfoUsage
from py_gitea_opensuse_org.models.node_info_usage_users import NodeInfoUsageUsers
from py_gitea_opensuse_org.models.note import Note
from py_gitea_opensuse_org.models.notification_count import NotificationCount
from py_gitea_opensuse_org.models.notification_subject import NotificationSubject
from py_gitea_opensuse_org.models.notification_thread import NotificationThread
from py_gitea_opensuse_org.models.o_auth2_application import OAuth2Application
from py_gitea_opensuse_org.models.organization import Organization
from py_gitea_opensuse_org.models.organization_permissions import OrganizationPermissions
from py_gitea_opensuse_org.models.pr_branch_info import PRBranchInfo
from py_gitea_opensuse_org.models.package import Package
from py_gitea_opensuse_org.models.package_file import PackageFile
from py_gitea_opensuse_org.models.payload_commit import PayloadCommit
from py_gitea_opensuse_org.models.payload_commit_verification import PayloadCommitVerification
from py_gitea_opensuse_org.models.payload_user import PayloadUser
from py_gitea_opensuse_org.models.permission import Permission
from py_gitea_opensuse_org.models.public_key import PublicKey
from py_gitea_opensuse_org.models.pull_request import PullRequest
from py_gitea_opensuse_org.models.pull_request_meta import PullRequestMeta
from py_gitea_opensuse_org.models.pull_review import PullReview
from py_gitea_opensuse_org.models.pull_review_comment import PullReviewComment
from py_gitea_opensuse_org.models.pull_review_request_options import PullReviewRequestOptions
from py_gitea_opensuse_org.models.push_mirror import PushMirror
from py_gitea_opensuse_org.models.reaction import Reaction
from py_gitea_opensuse_org.models.reference import Reference
from py_gitea_opensuse_org.models.release import Release
from py_gitea_opensuse_org.models.rename_org_option import RenameOrgOption
from py_gitea_opensuse_org.models.rename_user_option import RenameUserOption
from py_gitea_opensuse_org.models.repo_collaborator_permission import RepoCollaboratorPermission
from py_gitea_opensuse_org.models.repo_commit import RepoCommit
from py_gitea_opensuse_org.models.repo_create_release_attachment_request import RepoCreateReleaseAttachmentRequest
from py_gitea_opensuse_org.models.repo_topic_options import RepoTopicOptions
from py_gitea_opensuse_org.models.repo_transfer import RepoTransfer
from py_gitea_opensuse_org.models.repository import Repository
from py_gitea_opensuse_org.models.repository_meta import RepositoryMeta
from py_gitea_opensuse_org.models.search_results import SearchResults
from py_gitea_opensuse_org.models.secret import Secret
from py_gitea_opensuse_org.models.server_version import ServerVersion
from py_gitea_opensuse_org.models.stop_watch import StopWatch
from py_gitea_opensuse_org.models.submit_pull_review_options import SubmitPullReviewOptions
from py_gitea_opensuse_org.models.tag import Tag
from py_gitea_opensuse_org.models.tag_protection import TagProtection
from py_gitea_opensuse_org.models.team import Team
from py_gitea_opensuse_org.models.team_search200_response import TeamSearch200Response
from py_gitea_opensuse_org.models.timeline_comment import TimelineComment
from py_gitea_opensuse_org.models.topic_name import TopicName
from py_gitea_opensuse_org.models.topic_response import TopicResponse
from py_gitea_opensuse_org.models.tracked_time import TrackedTime
from py_gitea_opensuse_org.models.transfer_repo_option import TransferRepoOption
from py_gitea_opensuse_org.models.update_branch_protection_priories import UpdateBranchProtectionPriories
from py_gitea_opensuse_org.models.update_branch_repo_option import UpdateBranchRepoOption
from py_gitea_opensuse_org.models.update_file_options import UpdateFileOptions
from py_gitea_opensuse_org.models.update_repo_avatar_option import UpdateRepoAvatarOption
from py_gitea_opensuse_org.models.update_user_avatar_option import UpdateUserAvatarOption
from py_gitea_opensuse_org.models.update_variable_option import UpdateVariableOption
from py_gitea_opensuse_org.models.user import User
from py_gitea_opensuse_org.models.user_badge_option import UserBadgeOption
from py_gitea_opensuse_org.models.user_heatmap_data import UserHeatmapData
from py_gitea_opensuse_org.models.user_search200_response import UserSearch200Response
from py_gitea_opensuse_org.models.user_settings import UserSettings
from py_gitea_opensuse_org.models.user_settings_options import UserSettingsOptions
from py_gitea_opensuse_org.models.watch_info import WatchInfo
from py_gitea_opensuse_org.models.wiki_commit import WikiCommit
from py_gitea_opensuse_org.models.wiki_commit_list import WikiCommitList
from py_gitea_opensuse_org.models.wiki_page import WikiPage
from py_gitea_opensuse_org.models.wiki_page_meta_data import WikiPageMetaData



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.comment import Comment
from py_gitea_opensuse_org.models.issue import Issue
from py_gitea_opensuse_org.models.label import Label
from py_gitea_opensuse_org.models.milestone import Milestone
from py_gitea_opensuse_org.models.team import Team
from py_gitea_opensuse_org.models.tracked_time import TrackedTime
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class TimelineComment(BaseModel):
    """
    TimelineComment represents a timeline comment (comment of any type) on a commit or issue
    """ # noqa: E501
    assignee: Optional[User] = None
    assignee_team: Optional[Team] = None
    body: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    dependent_issue: Optional[Issue] = None
    html_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    issue_url: Optional[StrictStr] = None
    label: Optional[Label] = None
    milestone: Optional[Milestone] = None
    new_ref: Optional[StrictStr] = None
    new_title: Optional[StrictStr] = None
    old_milestone: Optional[Milestone] = None
    old_project_id: Optional[StrictInt] = None
    old_ref: Optional[StrictStr] = None
    old_title: Optional[StrictStr] = None
    project_id: Optional[StrictInt] = None
    pull_request_url: Optional[StrictStr] = None
    ref_action: Optional[StrictStr] = None
    ref_comment: Optional[Comment] = None
    ref_commit_sha: Optional[StrictStr] = Field(default=None, description="commit SHA where issue/PR was referenced")
    ref_issue: Optional[Issue] = None
    removed_assignee: Optional[StrictBool] = Field(default=None, description="whether the assignees were removed or added")
    resolve_doer: Optional[User] = None
    review_id: Optional[StrictInt] = None
    tracked_time: Optional[TrackedTime] = None
    type: Optional[StrictStr] = None
    updated_at: Optional[datetime] = None
    user: Optional[User] = None
    __properties: ClassVar[List[str]] = ["assignee", "assignee_team", "body", "created_at", "dependent_issue", "html_url", "id", "issue_url", "label", "milestone", "new_ref", "new_title", "old_milestone", "old_project_id", "old_ref", "old_title", "project_id", "pull_request_url", "ref_action", "ref_comment", "ref_commit_sha", "ref_issue", "removed_assignee", "resolve_doer", "review_id", "tracked_time", "type", "updated_at", "user"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TimelineComment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of assignee
        if self.assignee:
            _dict['assignee'] = self.assignee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assignee_team
        if self.assignee_team:
            _dict['assignee_team'] = self.assignee_team.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dependent_issue
        if self.dependent_issue:
            _dict['dependent_issue'] = self.dependent_issue.to_dict()
        # override the default output from pydantic by calling `to_dict()` of label
        if self.label:
            _dict['label'] = self.label.to_dict()
        # override the default output from pydantic by calling `to_dict()` of milestone
        if self.milestone:
            _dict['milestone'] = self.milestone.to_dict()
        # override the default output from pydantic by calling `to_dict()` of old_milestone
        if self.old_milestone:
            _dict['old_milestone'] = self.old_milestone.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ref_comment
        if self.ref_comment:
            _dict['ref_comment'] = self.ref_comment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ref_issue
        if self.ref_issue:
            _dict['ref_issue'] = self.ref_issue.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resolve_doer
        if self.resolve_doer:
            _dict['resolve_doer'] = self.resolve_doer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tracked_time
        if self.tracked_time:
            _dict['tracked_time'] = self.tracked_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TimelineComment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assignee": User.from_dict(obj["assignee"]) if obj.get("assignee") is not None else None,
            "assignee_team": Team.from_dict(obj["assignee_team"]) if obj.get("assignee_team") is not None else None,
            "body": obj.get("body"),
            "created_at": obj.get("created_at"),
            "dependent_issue": Issue.from_dict(obj["dependent_issue"]) if obj.get("dependent_issue") is not None else None,
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "issue_url": obj.get("issue_url"),
            "label": Label.from_dict(obj["label"]) if obj.get("label") is not None else None,
            "milestone": Milestone.from_dict(obj["milestone"]) if obj.get("milestone") is not None else None,
            "new_ref": obj.get("new_ref"),
            "new_title": obj.get("new_title"),
            "old_milestone": Milestone.from_dict(obj["old_milestone"]) if obj.get("old_milestone") is not None else None,
            "old_project_id": obj.get("old_project_id"),
            "old_ref": obj.get("old_ref"),
            "old_title": obj.get("old_title"),
            "project_id": obj.get("project_id"),
            "pull_request_url": obj.get("pull_request_url"),
            "ref_action": obj.get("ref_action"),
            "ref_comment": Comment.from_dict(obj["ref_comment"]) if obj.get("ref_comment") is not None else None,
            "ref_commit_sha": obj.get("ref_commit_sha"),
            "ref_issue": Issue.from_dict(obj["ref_issue"]) if obj.get("ref_issue") is not None else None,
            "removed_assignee": obj.get("removed_assignee"),
            "resolve_doer": User.from_dict(obj["resolve_doer"]) if obj.get("resolve_doer") is not None else None,
            "review_id": obj.get("review_id"),
            "tracked_time": TrackedTime.from_dict(obj["tracked_time"]) if obj.get("tracked_time") is not None else None,
            "type": obj.get("type"),
            "updated_at": obj.get("updated_at"),
            "user": User.from_dict(obj["user"]) if obj.get("user") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.action_workflow_run import ActionWorkflowRun
from typing import Optional, Set
from typing_extensions import Self

class ActionArtifact(BaseModel):
    """
    ActionArtifact represents a ActionArtifact
    """ # noqa: E501
    archive_download_url: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    expired: Optional[StrictBool] = None
    expires_at: Optional[datetime] = None
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    size_in_bytes: Optional[StrictInt] = None
    updated_at: Optional[datetime] = None
    url: Optional[StrictStr] = None
    workflow_run: Optional[ActionWorkflowRun] = None
    __properties: ClassVar[List[str]] = ["archive_download_url", "created_at", "expired", "expires_at", "id", "name", "size_in_bytes", "updated_at", "url", "workflow_run"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActionArtifact from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of workflow_run
        if self.workflow_run:
            _dict['workflow_run'] = self.workflow_run.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActionArtifact from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "archive_download_url": obj.get("archive_download_url"),
            "created_at": obj.get("created_at"),
            "expired": obj.get("expired"),
            "expires_at": obj.get("expires_at"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "size_in_bytes": obj.get("size_in_bytes"),
            "updated_at": obj.get("updated_at"),
            "url": obj.get("url"),
            "workflow_run": ActionWorkflowRun.from_dict(obj["workflow_run"]) if obj.get("workflow_run") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.22.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.badge import Badge


class TestBadge(unittest.TestCase):
    """Badge unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Badge:
        """Test Badge
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Badge`
        """
        model = Badge()
        if include_optional:
            return Badge(
                description = '',
                id = 56,
                image_url = '',
                slug = ''
            )
        else:
            return Badge(
        )
        """

    def testBadge(self):
        """Test Badge"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.wiki_page import WikiPage  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestWikiPage(unittest.TestCase):
    """WikiPage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WikiPage
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `WikiPage`
        """
        model = py_gitea_opensuse_org.models.wiki_page.WikiPage()  # noqa: E501
        if include_optional :
            return WikiPage(
                commit_count = 56, 
                content_base64 = '', 
                footer = '', 
                html_url = '', 
                last_commit = py_gitea_opensuse_org.models.wiki_commit.WikiCommit(
                    author = py_gitea_opensuse_org.models.commit_user_contains_information_of_a_user_in_the_context_of_a_commit/.CommitUser contains information of a user in the context of a commit.(
                        date = '', 
                        email = '', 
                        name = '', ), 
                    commiter = py_gitea_opensuse_org.models.commit_user_contains_information_of_a_user_in_the_context_of_a_commit/.CommitUser contains information of a user in the context of a commit.(
                        date = '', 
                        email = '', 
                        name = '', ), 
                    message = '', 
                    sha = '', ), 
                sidebar = '', 
                sub_url = '', 
                title = ''
            )
        else :
            return WikiPage(
        )
        """

    def testWikiPage(self):
        """Test WikiPage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
